https://git.reactos.org/?p=reactos.git;a=commitdiff;h=9e2ae9b05c4c8d29bcddf1dcae1cb469450c0c71

commit 9e2ae9b05c4c8d29bcddf1dcae1cb469450c0c71
Author:     Eric Kohl <[email protected]>
AuthorDate: Sun Jan 19 13:33:15 2020 +0100
Commit:     Eric Kohl <[email protected]>
CommitDate: Sun Jan 19 13:34:32 2020 +0100

    [SYSSETUP] When the physical host name is set, also set an empty physical 
domain name
---
 dll/win32/syssetup/wizard.c | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/dll/win32/syssetup/wizard.c b/dll/win32/syssetup/wizard.c
index d0b4dca711c..bd5e6118301 100644
--- a/dll/win32/syssetup/wizard.c
+++ b/dll/win32/syssetup/wizard.c
@@ -556,7 +556,10 @@ WriteComputerSettings(WCHAR * ComputerName, HWND hwndDlg)
         return FALSE;
     }
 
-    /* Try to also set DNS hostname */
+    /* Set the physical DNS domain */
+    SetComputerNameExW(ComputerNamePhysicalDnsDomain, L"");
+
+    /* Set the physical DNS hostname */
     SetComputerNameExW(ComputerNamePhysicalDnsHostname, ComputerName);
 
     /* Set the accounts domain name */

Reply via email to